==> owncloud-4.0.4.tgz: owncloud/apps/contacts/l10n/hu_HU.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Címlista (de)aktiválása sikertelen",
"There was an error adding the contact." => "Hiba a kapcsolat hozzáadásakor",
"Cannot add empty property." => "Nem adható hozzá üres tulajdonság",
"At least one of the address fields has to be filled out." => "Legalább egy címmező kitöltendő",
"Trying to add duplicate property: " => "Kísérlet dupla tulajdonság hozzáadására: ",
"Error adding contact property." => "Hiba a kapcsolat-tulajdonság hozzáadásakor",
"No ID provided" => "Nincs ID megadva",
"Error setting checksum." => "Hiba az ellenőrzőösszeg beállításakor",
"No categories selected for deletion." => "Nincs kiválasztva törlendő kategória",
"No address books found." => "Nem található címlista",
"No contacts found." => "Nem található kontakt",
"Missing ID" => "Hiányzó ID",
"Error parsing VCard for ID: \"" => "VCard elemzése sikertelen a következő ID-hoz: \"",
"Cannot add addressbook with an empty name." => "Nem adható hozzá névtelen címlista",
"Error adding addressbook." => "Hiba a címlista hozzáadásakor",
"Error activating addressbook." => "Címlista aktiválása sikertelen",
"No contact ID was submitted." => "Nincs ID megadva a kontakthoz",
"Error reading contact photo." => "A kontakt képének beolvasása sikertelen",
"Error saving temporary file." => "Ideiglenes fájl mentése sikertelen",
"The loading photo is not valid." => "A kép érvénytelen",
"id is not set." => "ID nincs beállítva",
"Information about vCard is incorrect. Please reload the page." => "A vCardról szóló információ helytelen. Töltsd újra az oldalt.",
"Error deleting contact property." => "Hiba a kapcsolat-tulajdonság törlésekor",
"Contact ID is missing." => "Hiányzik a kapcsolat ID",
"Missing contact id." => "Hiányzik a kontakt ID",
"No photo path was submitted." => "Nincs fénykép-útvonal megadva",
"File doesn't exist:" => "A fájl nem létezik:",
"Error loading image." => "Kép betöltése sikertelen",
"element name is not set." => "az elem neve nincs beállítva",
"checksum is not set." => "az ellenőrzőösszeg nincs beállítva",
"Information about vCard is incorrect. Please reload the page: " => "Helytelen információ a vCardról. Töltse újra az oldalt: ",
"Something went FUBAR. " => "Valami balul sült el.",
"Error updating contact property." => "Hiba a kapcsolat-tulajdonság frissítésekor",
"Cannot update addressbook with an empty name." => "Üres névvel nem frissíthető a címlista",
"Error updating addressbook." => "Hiba a címlista frissítésekor",
"Error uploading contacts to storage." => "Hiba a kapcsolatok feltöltésekor",
"There is no error, the file uploaded with success" => "Nincs hiba, a fájl sikeresen feltöltődött",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "A feltöltött fájl mérete meghaladja az upload_max_filesize értéket a php.ini-ben",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "A feltöltött fájl mérete meghaladja a HTML form-ban megadott MAX_FILE_SIZE értéket",
"The uploaded file was only partially uploaded" => "A fájl csak részlegesen lett feltöltve",
"No file was uploaded" => "Nincs feltöltött fájl",
"Missing a temporary folder" => "Hiányzik az ideiglenes könyvtár",
"Contacts" => "Kapcsolatok",
"Drop a VCF file to import contacts." => "Húzza ide a VCF fájlt a kapcsolatok importálásához",
"Addressbook not found." => "Címlista nem található",
"This is not your addressbook." => "Ez nem a te címjegyzéked.",
"Contact could not be found." => "Kapcsolat nem található.",
"Address" => "Cím",
"Telephone" => "Telefonszám",
"Email" => "E-mail",
"Organization" => "Szervezet",
"Work" => "Munkahelyi",
"Home" => "Otthoni",
"Mobile" => "Mobiltelefonszám",
"Text" => "Szöveg",
"Voice" => "Hang",
"Message" => "Üzenet",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Személyhívó",
"Internet" => "Internet",
"{name}'s Birthday" => "{name} születésnapja",
"Contact" => "Kapcsolat",
"Add Contact" => "Kapcsolat hozzáadása",
"Addressbooks" => "Címlisták",
"Configure Address Books" => "Címlisták beállítása",
"New Address Book" => "Új címlista",
"Import from VCF" => "Importálás VCF-ből",
"CardDav Link" => "CardDav hivatkozás",
"Download" => "Letöltés",
"Edit" => "Szerkesztés",
"Delete" => "Törlés",
"Download contact" => "Kapcsolat letöltése",
"Delete contact" => "Kapcsolat törlése",
"Drop photo to upload" => "Húzza ide a feltöltendő képet",
"Format custom, Short name, Full name, Reverse or Reverse with comma" => "Formátum egyedi, Rövid név, Teljes név, Visszafelé vagy Visszafelé vesszővel",
"Edit name details" => "Név részleteinek szerkesztése",
"Nickname" => "Becenév",
"Enter nickname" => "Becenév megadása",
"Birthday" => "Születésnap",
"dd-mm-yyyy" => "yyyy-mm-dd",
"Groups" => "Csoportok",
"Separate groups with commas" => "Vesszővel válassza el a csoportokat",
"Edit groups" => "Csoportok szerkesztése",
"Preferred" => "Előnyben részesített",
"Please specify a valid email address." => "Adjon meg érvényes email címet",
"Enter email address" => "Adja meg az email címet",
"Mail to address" => "Postai cím",
"Delete email address" => "Email cím törlése",
"Enter phone number" => "Adja meg a telefonszámot",
"Delete phone number" => "Telefonszám törlése",
"View on map" => "Megtekintés a térképen",
"Edit address details" => "Cím részleteinek szerkesztése",
"Add notes here." => "Megjegyzések",
"Add field" => "Mező hozzáadása",
"Profile picture" => "Profilkép",
"Phone" => "Telefonszám",
"Note" => "Jegyzet",
"Delete current photo" => "Aktuális kép törlése",
"Edit current photo" => "Aktuális kép szerkesztése",
"Upload new photo" => "Új kép feltöltése",
"Select photo from ownCloud" => "Kép kiválasztása ownCloud-ból",
"Edit address" => "Cím szerkesztése",
"Type" => "Típus",
"PO Box" => "Postafiók",
"Extended" => "Kiterjesztett",
"Street" => "Utca",
"City" => "Város",
"Region" => "Megye",
"Zipcode" => "Irányítószám",
"Country" => "Ország",
"Edit categories" => "Kategóriák szerkesztése",
"Add" => "Hozzáad",
"Addressbook" => "Címlista",
"Hon. prefixes" => "Előtag",
"Miss" => "Miss",
"Ms" => "Ms",
"Mr" => "Mr",
"Sir" => "Sir",
"Mrs" => "Mrs",
"Dr" => "Dr.",
"Given name" => "Teljes név",
"Additional names" => "További nevek",
"Family name" => "Családnév",
"Hon. suffixes" => "Utótag",
"J.D." => "J.D.",
"M.D." => "M.D.",
"D.O." => "D.O.",
"D.C." => "D.C.",
"Ph.D." => "Ph.D.",
"Esq." => "Esq.",
"Jr." => "Ifj.",
"Sn." => "Id.",
"New Addressbook" => "Új Címlista",
"Edit Addressbook" => "Címlista szerkesztése",
"Displayname" => "Megjelenített név",
"Active" => "Aktív",
"Save" => "Mentés",
"Submit" => "Elküld",
"Cancel" => "Mégsem",
"Import a contacts file" => "Kapcsolat-fájl importálása",
"Please choose the addressbook" => "Válassza ki a címlistát",
"create a new addressbook" => "Címlista létrehozása",
"Name of new addressbook" => "Új címlista neve",
"Import" => "Import",
"Importing contacts" => "Kapcsolatok importálása",
"Select address book to import to:" => "Melyik címlistába történjen az importálás:",
"Select from HD" => "Kiválasztás merevlemezről",
"You have no contacts in your addressbook." => "Nincsenek kapcsolatok a címlistában",
"Add contact" => "Kapcsolat hozzáadása",
"Configure addressbooks" => "Címlisták beállítása",
"CardDAV syncing addresses" => "CardDAV szinkronizációs címek",
"more info" => "további információ",
"Primary address (Kontact et al)" => "Elsődleges cím",
"iOS/OS X" => "iOS/OS X"
);

==> owncloud-4.5.7.tgz: owncloud/apps/contacts/l10n/hu_HU.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Címlista (de)aktiválása sikertelen",
"id is not set." => "ID nincs beállítva",
"Cannot update addressbook with an empty name." => "Üres névvel nem frissíthető a címlista",
"No ID provided" => "Nincs ID megadva",
"Error setting checksum." => "Hiba az ellenőrzőösszeg beállításakor",
"No categories selected for deletion." => "Nincs kiválasztva törlendő kategória",
"No address books found." => "Nem található címlista",
"No contacts found." => "Nem található kontakt",
"element name is not set." => "az elem neve nincs beállítva",
"Cannot add empty property." => "Nem adható hozzá üres tulajdonság",
"At least one of the address fields has to be filled out." => "Legalább egy címmező kitöltendő",
"Trying to add duplicate property: " => "Kísérlet dupla tulajdonság hozzáadására: ",
"Information about vCard is incorrect. Please reload the page." => "A vCardról szóló információ helytelen. Töltsd újra az oldalt.",
"Missing ID" => "Hiányzó ID",
"Error parsing VCard for ID: \"" => "VCard elemzése sikertelen a következő ID-hoz: \"",
"checksum is not set." => "az ellenőrzőösszeg nincs beállítva",
"Information about vCard is incorrect. Please reload the page: " => "Helytelen információ a vCardról. Töltse újra az oldalt: ",
"Something went FUBAR. " => "Valami balul sült el.",
"No contact ID was submitted." => "Nincs ID megadva a kontakthoz",
"Error reading contact photo." => "A kontakt képének beolvasása sikertelen",
"Error saving temporary file." => "Ideiglenes fájl mentése sikertelen",
"The loading photo is not valid." => "A kép érvénytelen",
"Contact ID is missing." => "Hiányzik a kapcsolat ID",
"No photo path was submitted." => "Nincs fénykép-útvonal megadva",
"File doesn't exist:" => "A fájl nem létezik:",
"Error loading image." => "Kép betöltése sikertelen",
"Error getting contact object." => "A kontakt-objektum feldolgozása sikertelen",
"Error getting PHOTO property." => "A PHOTO-tulajdonság  feldolgozása sikertelen",
"Error saving contact." => "A kontakt mentése sikertelen",
"Error resizing image" => "Képméretezés sikertelen",
"Error cropping image" => "Képvágás sikertelen",
"Error creating temporary image" => "Ideiglenes kép létrehozása sikertelen",
"Error finding image: " => "A kép nem található",
"Error uploading contacts to storage." => "Hiba a kapcsolatok feltöltésekor",
"There is no error, the file uploaded with success" => "Nincs hiba, a fájl sikeresen feltöltődött",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "A feltöltött fájl mérete meghaladja az upload_max_filesize értéket a php.ini-ben",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "A feltöltött fájl mérete meghaladja a HTML form-ban megadott MAX_FILE_SIZE értéket",
"The uploaded file was only partially uploaded" => "A fájl csak részlegesen lett feltöltve",
"No file was uploaded" => "Nincs feltöltött fájl",
"Missing a temporary folder" => "Hiányzik az ideiglenes könyvtár",
"Couldn't save temporary image: " => "Ideiglenes kép létrehozása sikertelen",
"Couldn't load temporary image: " => "Ideiglenes kép betöltése sikertelen",
"No file was uploaded. Unknown error" => "Nem történt feltöltés. Ismeretlen hiba",
"Contacts" => "Kapcsolatok",
"Sorry, this functionality has not been implemented yet" => "Sajnáljuk, ez a funkció még nem támogatott",
"Not implemented" => "Nem támogatott",
"Couldn't get a valid address." => "Érvényes cím lekérése sikertelen",
"Error" => "Hiba",
"Format custom, Short name, Full name, Reverse or Reverse with comma" => "Formátum egyedi, Rövid név, Teljes név, Visszafelé vagy Visszafelé vesszővel",
"Select type" => "Típus kiválasztása",
"This property has to be non-empty." => "Ezt a tulajdonságot muszáj kitölteni",
"Couldn't serialize elements." => "Sorbarakás sikertelen",
"'deleteProperty' called without type argument. Please report at bugs.owncloud.org" => "A 'deleteProperty' argumentum nélkül lett meghívva. Kérjük, jelezze a hibát.",
"Edit name" => "Név szerkesztése",
"No files selected for upload." => "Nincs kiválasztva feltöltendő fájl",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "A feltöltendő fájl mérete meghaladja a megengedett mértéket",
"Result: " => "Eredmény: ",
" imported, " => "  beimportálva,  ",
" failed." => "  sikertelen",
"Download" => "Letöltés",
"Edit" => "Szerkesztés",
"Delete" => "Törlés",
"Cancel" => "Mégsem",
"This is not your addressbook." => "Ez nem a te címjegyzéked.",
"Contact could not be found." => "Kapcsolat nem található.",
"Work" => "Munkahelyi",
"Home" => "Otthoni",
"Mobile" => "Mobiltelefonszám",
"Text" => "Szöveg",
"Voice" => "Hang",
"Message" => "Üzenet",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Személyhívó",
"Internet" => "Internet",
"Birthday" => "Születésnap",
"{name}'s Birthday" => "{name} születésnapja",
"Contact" => "Kapcsolat",
"Add Contact" => "Kapcsolat hozzáadása",
"Import" => "Import",
"Close" => "Bezár",
"Drop photo to upload" => "Húzza ide a feltöltendő képet",
"Delete current photo" => "Aktuális kép törlése",
"Edit current photo" => "Aktuális kép szerkesztése",
"Upload new photo" => "Új kép feltöltése",
"Select photo from ownCloud" => "Kép kiválasztása ownCloud-ból",
"Edit name details" => "Név részleteinek szerkesztése",
"Organization" => "Szervezet",
"Nickname" => "Becenév",
"Enter nickname" => "Becenév megadása",
"dd-mm-yyyy" => "yyyy-mm-dd",
"Groups" => "Csoportok",
"Separate groups with commas" => "Vesszővel válassza el a csoportokat",
"Edit groups" => "Csoportok szerkesztése",
"Preferred" => "Előnyben részesített",
"Please specify a valid email address." => "Adjon meg érvényes email címet",
"Enter email address" => "Adja meg az email címet",
"Mail to address" => "Postai cím",
"Delete email address" => "Email cím törlése",
"Enter phone number" => "Adja meg a telefonszámot",
"Delete phone number" => "Telefonszám törlése",
"View on map" => "Megtekintés a térképen",
"Edit address details" => "Cím részleteinek szerkesztése",
"Add notes here." => "Megjegyzések",
"Add field" => "Mező hozzáadása",
"Phone" => "Telefonszám",
"Email" => "E-mail",
"Address" => "Cím",
"Note" => "Jegyzet",
"Download contact" => "Kapcsolat letöltése",
"Delete contact" => "Kapcsolat törlése",
"The temporary image has been removed from cache." => "Az ideiglenes kép el lett távolítva a gyorsítótárból",
"Edit address" => "Cím szerkesztése",
"Type" => "Típus",
"PO Box" => "Postafiók",
"Extended" => "Kiterjesztett",
"City" => "Város",
"Region" => "Megye",
"Zipcode" => "Irányítószám",
"Country" => "Ország",
"Addressbook" => "Címlista",
"Hon. prefixes" => "Előtag",
"Miss" => "Miss",
"Ms" => "Ms",
"Mr" => "Mr",
"Sir" => "Sir",
"Mrs" => "Mrs",
"Dr" => "Dr.",
"Given name" => "Teljes név",
"Additional names" => "További nevek",
"Family name" => "Családnév",
"Hon. suffixes" => "Utótag",
"J.D." => "J.D.",
"M.D." => "M.D.",
"D.O." => "D.O.",
"D.C." => "D.C.",
"Ph.D." => "Ph.D.",
"Esq." => "Esq.",
"Jr." => "Ifj.",
"Sn." => "Id.",
"Import a contacts file" => "Kapcsolat-fájl importálása",
"Please choose the addressbook" => "Válassza ki a címlistát",
"create a new addressbook" => "Címlista létrehozása",
"Name of new addressbook" => "Új címlista neve",
"Importing contacts" => "Kapcsolatok importálása",
"Add contact" => "Kapcsolat hozzáadása",
"CardDAV syncing addresses" => "CardDAV szinkronizációs címek",
"more info" => "további információ",
"Primary address (Kontact et al)" => "Elsődleges cím",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Címlisták",
"New Address Book" => "Új címlista",
"Save" => "Mentés"
);
